#include "wwplugins.h"
#include "wwclasses.h"
#ifndef NO_WWPLOT
#include "wwplot.h"
#endif
#include "wwlineedit.h"
#include "icons.h"
#include <qcanvas.h>
#include <qworkspace.h>
#include <qtabbar.h>
#include <qgl.h>

Q_EXPORT_PLUGIN( wwPlugins )

/**
@mainpage   wwWidgets
@author     Witold Wysota
 
This is a set of widgets for Qt3 with a plugin that makes them available in Qt Designer.
 
*/


wwPlugins::wwPlugins() {}
QStringList wwPlugins::keys() const {
    QStringList list;
    list << "wwActiveLabel";
    list << "QCanvasView";
    list << "QWorkspace";
#ifndef NO_WWPLOT

    list << "wwPlot";
#endif

    list << "QGLWidget";
    list << "wwLineEdit";
    return list;
}
QWidget* wwPlugins::create( const QString &key, QWidget* parent, const char* name ) {
    if ( key == "wwActiveLabel" )
        return new wwActiveLabel( parent, name );
    if ( key == "QCanvasView" )
        return new QCanvasView( parent, name );
    if ( key == "QWorkspace" )
        return new QWorkspace( parent, name );
    if ( key == "QGLWidget" )
        return new QGLWidget( parent, name );
#ifndef NO_WWPLOT
    if ( key == "wwPlot" )
        return new wwPlot( parent, name );
#endif

    if ( key == "wwLineEdit" )
        return new wwLineEdit( parent, name );
    return 0;
}

QString wwPlugins::group( const QString& feature ) const {
    if ( feature == "wwActiveLabel" )
        return "wwClasses";
#ifndef NO_WWPLOT

    if ( feature == "wwPlot" )
        return "wwClasses";
#endif

    if ( feature == "QCanvasView" )
        return "Views";
    if ( feature == "QWorkspace" )
        return "Views";
    if ( feature == "QGLWidget" )
        return "Display";
    if ( feature == "wwLineEdit" )
        return "wwClasses";

    return QString::null;
}

QIconSet wwPlugins::iconSet( const QString& feature ) const {
    if(feature == "wwLineEdit")
        return QIconSet( QPixmap( (const char**)lineedit_xpm));
    if(feature == "wwActiveLabel")
        return QIconSet( QPixmap( (const char**)label_xpm));
    if(feature == "QGLWidget")
        return QIconSet( QPixmap( (const char**)glwidget_xpm));
#ifndef NO_WWPLOT
    if(feature == "wwPlot")
        return QIconSet( QPixmap( (const char**)plot_xpm));
#endif

    return QIconSet( QPixmap( (const char**)wwxpm ) );
}

QString wwPlugins::includeFile( const QString& feature ) const {
    if ( feature == "wwActiveLabel" )
        return "wwclasses.h";
#ifndef NO_WWPLOT
    if ( feature == "wwPlot" )
        return "wwplot.h";
#endif
    if ( feature == "QCanvasView" )
        return "qcanvas.h";
    if ( feature == "QWorkspace" )
        return "qworkspace.h";
    if ( feature == "QGLWidget" )
        return "qgl.h";
    if ( feature == "wwLineEdit" )
        return "wwlineedit.h";
    return QString::null;
}

QString wwPlugins::toolTip( const QString& feature ) const {
    if ( feature == "wwActiveLabel" )
        return "wwActiveLabel";
    if ( feature == "QCanvasView" )
        return "QCanvasView";
    if ( feature == "QWorkspace" )
        return "QWorkspace";
    if ( feature == "wwLineEdit" )
        return "wwLineEdit";
    return QString::null;
}

QString wwPlugins::whatsThis( const QString& feature ) const {
    if ( feature == "wwActiveLabel" )
        return "wwActiveLabel";
    if ( feature == "QCanvasView" )
        return "QCanvasView";
    if ( feature == "QWorkspace" )
        return "QWorkspace";
    if ( feature == "wwLineEdit" )
        return "LineEdit with Regexp validator";
    return QString::null;
}
bool wwPlugins::isContainer( const QString& feature) const {
    if ( feature == "wwActivaLabel" )
        return FALSE;
    if ( feature == "QCanvasView" )
        return FALSE;
    if ( feature == "QWorkspace" )
        return FALSE;
    return FALSE;
}
